// STM32F103C8T6
// 周波数カウンター Frequency counter（別名：OCXO　校正器:Calibrator）
// 2020/05/25
// 2025/01/05:誤記を訂正(PB3をPB13に訂正）
// 2025/01/26:ADS1115 の定義を追加した。
//

//#define DEBUG_LOG             // 一時的デバッグ用ログ情報を使用時に使うVcon用
//#define DEBUG_MODE            // DEBUG　オシロスコープでの確認用

//  OCXOのVc端子の電圧をADS1115で検出しLOGに出力する処理を追加。（開発者(私)限定の機能の更新）
//#define ADS1115d              // V50_67  2025/01/26  ADS1115 Differential_MODE

// ===================================================
/* V50_65 で追加した遅延スタート機能
    10,15,20,30分遅れ指定が可能
　　不要時は非選択とすること。　　2024/03/02　　　*/
//#define DELAY_START           // V50_65  遅延スタート用
// ===================================================
/* ソフトリセット機能　ON/OFF (TFT専用)*/
//#define SOFT_RESET  // PB0 HIGH ==> RESET(2021/02/01:TRによる回路必要)
// ソフトリセット選択時は、ブザーは内側から見て左側のPB13とすること。(2025/01/05:PB3をPB13に誤記を訂正）
// ===================================================
/* OCXOの自動較正モード OCXO Vcon 
　　専用PCBにてDAC(MCP4726)と連携する (TFT専用)
　　Vcon選択時は両方を有効にすること。　　　　　*/
//#define OPTION_OCXO_Vcon      // I2C 0x60 以下のどちらかのデバイスを選択する。

#define OPTION_VCON_MCP4726   // MCP4726 Select
//#define OPTION_VCON_MCP4725   // MCP4725 Select （未テストにつき選択しない）
// ===================================================
/* 電子ブザーの有無を選択　有りの場合は
　　以下の電子ブザーのポートを選択 */
#define BOARD_V5_BUZZER         // BUZZER=PB0 または PB13 を使用する

/* 電子ブザーのポートを選択　何れか*/
//#define BUZZER_PORT_PB0     // ディスプレー側から見てSTM32F103の右側（初期位置）
#define BUZZER_PORT_PB13    // ディスプレー側から見てSTM32F103の左側（大きいケースで使用中）
// #define BUZZER_PORT_PB5    // PCB V5.1 より選択可（2022/09/16より）
// ===================================================
/* 表示器の選択(何れか） */
// #define OPTION_SSD1309_OLED  // Input ANALOG_4_BUTTON_SW  V50_65移行は■選択無効■
#define OPTION_ILI9341_TFT		// Input XPT2046_TOUCH_SW
// ===================================================
/* GPS受信機の選択(何れか） */
//#define OPTION_AE_GNSS
#define OPTION_UBLOX_NEO

/* OPTION_UBLOX_NEO を選択した場合
　　UBlox NEO-7M M8N の識別(何れか） */
//#define SEL_UBLOX_NEO_7M
#define SEL_UBLOX_NEO_M8N
// ===================================================
/* 温度センサー使用
//  ■■先ずは、温度センサーを使うか／使わないかを設定■■
*/ 
//#define OPTION_USE_TEMPERATURE_SENSOR   // OLEDでは温度センサーは選択しないこと。

/* 温度センサーの種類を選択（いずれか一つを選択）
// 
//  ■■次に、使用するセンサーの種類を設定する。■■
//  更にセンサー校正用に、電圧値をそのまま表示する選択もあり。

//     OLED(No1) ===>LM61 ===>MPC9700A(2020/10/15)==>採用しない。
//     TFT大(No2) ===>MPC9700A ===> TMP36(2020/10/23)
//     TFT小(No3) ===>LM61
*/
//#define OPTION_TEMPERATURE_SENSOR_LM61    //  TFT小(No3)
#define OPTION_TEMPERATURE_SENSOR_TMP36   // TFT大(No2)
//#define SENSOR_TEST_MODE    // 温度センサー値を電圧値として表示する。(mV表示)


/*
 * 
 * UBlox ENO-7M M8N の識別は、以下の条件式で選択する(2020/06/07)
 * #if defined(OPTION_UBLOX_NEO) && defined(SEL_UBLOX_NEO_M8N)
 * #if defined(OPTION_UBLOX_NEO) && defined(SEL_UBLOX_NEO_7M)
 * 
 * 2020/07/17現在、温度センサーLM61は、OLEDタイプに接続。
 * 　　　　　　　　　　　　　　MPC9700Aは、TFTタイプに接続中。
 */
// ===================================================
//
//
